import 'package:flutter/material.dart';

enum PageState{
  Error,
  Loading,
  Data
}

class PageX extends StatelessWidget {
  final Widget data;
  final PageState pageState;
  final String? message;
  final String errorButtonText;
  final Function errorButtonPressed;
  PageX({required this.data, required this.pageState, this.message, required this.errorButtonText, required this.errorButtonPressed});

  Widget loaderWidget(){
    return Center(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          SizedBox(
            height: 20,
            width: 20,
            child: CircularProgressIndicator(
              strokeWidth: 2,
              backgroundColor: Colors.grey.shade200,
            ),
          ),
          if((message ?? "") != "")SizedBox(height: 6,),
          Text(message ?? "",style: TextStyle(fontSize: 15, height: 1.5, color: Colors.black),),
        ],
      ),
    );
  }

  Widget errorWidget(BuildContext context){
    return Container(
      alignment: Alignment.center,
      padding: EdgeInsets.symmetric(horizontal: 20),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          Text(message ?? "",style: TextStyle(fontSize: 15, height: 1.5, color: Colors.black),),
          SizedBox(height: 20,),
          MaterialButton(
              elevation: 0,
              onPressed: (){
                errorButtonPressed();
              },
              color: Theme.of(context).primaryColor,
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(4)
              ),
              child: Text(errorButtonText,style: TextStyle(color: Colors.white),),
          ),
        ],
      ),
    );
  }

  Widget bodyWidget(BuildContext context){
    if(pageState == PageState.Loading){
      return loaderWidget();
    }else if(pageState == PageState.Error){
      return errorWidget(context);
    }else if(pageState == PageState.Data){
      return data;
    }else{
      return Container();
    }
  }


  @override
  Widget build(BuildContext context) {
    return bodyWidget(context);
  }
}
